@@ -212,27 +212,27 @@ class IotToS3(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="iotActionsRole")
     def iot_actions_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "iotActionsRole"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="iotTopicRule")
     def iot_topic_rule(self) -> aws_cdk.aws_iot.CfnTopicRule:
         return typing.cast(aws_cdk.aws_iot.CfnTopicRule, jsii.get(self, "iotTopicRule"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3BucketInterface")
     def s3_bucket_interface(self) -> aws_cdk.aws_s3.IBucket:
         return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "s3BucketInterface"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3Bucket")
     def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3Bucket"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "s3LoggingBucket"))
@@ -272,11 +272,11 @@ class IotToS3Props:
         :summary: The properties for the IotToS3 class.
         '''
         if isinstance(iot_topic_rule_props, dict):
-            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
+            iot_topic_rule_props = CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(bucket_props, dict):
-            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
+            bucket_props = BucketProps(**bucket_props)
         if isinstance(logging_bucket_props, dict):
-            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
+            logging_bucket_props = BucketProps(**logging_bucket_props)
         if __debug__:
             type_hints = typing.get_type_hints(IotToS3Props.__init__)
             check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
